import { mapGetters } from 'vuex'

export default {
    computed: {
        ...mapGetters('general', ['permissions']),
        /**
         * Checks whether the user can view auction section.
         *
         * @returns { Boolean } - can or can't view
         */
        can_view() {
            return this.permissions.includes('ferda_auction.can_view')
        },
        /**
         * Checks whether the user can view ban list.
         *
         * @returns { Boolean } - can or can't view
         */
        can_view_ban() {
            return this.permissions.includes('ferda_auction.can_view_ban')
        },
        /**
         * Checks whether the user can view confidential information about auctions.
         *
         * @returns { Boolean } - can or can't view
         */
        can_view_all() {
            return this.permissions.includes('ferda_auction.can_view_all')
        },
        /**
         * Checks whether the user can edit ban
         *
         * @returns { Boolean } - can or can't edit
         */
        can_edit_ban() {
            return this.permissions.includes('ferda_auction.can_edit_ban')
        },
        /**
         * Checks whether the user can stop and resume auctions.
         *
         * @returns { Boolean } - can or can't stop/resume
         */
        can_edit_auction() {
            return this.permissions.includes('ferda_auction.can_edit_auction')
        },
    },
}
