export const AUCTION_TYPE = Object.freeze({
    CREATE_MANUAL_BLACKLIST: 'create_manual_blacklist',
    CANCEL_MANUAL_BLACKLIST: 'cancel_manual_blacklist',
    CANCEL_AUTOMATIC_BLACKLIST_CLOSE: 'cancel_automatic_blacklist_close',
    CANCEL_AUTOMATIC_BLACKLIST_DONT_CLOSE: 'cancel_automatic_blacklist_dont_close',
})

export const AUCTION_ACCESS_TOKEN = 'auction_token'

export const DATE_RANGE = Object.freeze({
    CURRENT_DAY: 'current_day',
    PAST_DAY: 'past_day',
    CURRENT_WEEK: 'current_week',
    PAST_WEEK: 'past_week',
    CURRENT_MONTH: 'current_month',
    PAST_MONTH: 'past_month',
    PAST_6_MONTHS: 'past_6_months',
})

export const ROUND_PHASE = Object.freeze({
    NEW: 'new',
    IN_AUCTION: 'in_auction',
    PENDING_PAYMENT: 'pending_payment',
    PENDING_REGISTRATION: 'pending_registration',
    FINISHED_NO_BID: 'finished_no_bid',
    PENDING_PENALTY: 'pending_penalty',
    PAID_PENALTY: 'paid_penalty',
    CANCELED_PENALTY: 'canceled_penalty',
    FINISHED_NOT_TAKEN: 'finished_not_taken',
    FINISHED_SUCCESS: 'finished_success',
    STOPPED: 'stopped',
    DELETED: 'deleted',
})

export const ROUND_STATUS = Object.freeze({
    NEW: 'new',
    IN_AUCTION: 'in_auction',
    PENDING_PAYMENT: 'pending_payment',
    PENDING_REGISTRATION: 'pending_registration',
    FINISHED_NO_BID: 'finished_no_bid',
    FINISHED_NOT_PAID: 'finished_not_paid',
    FINISHED_NOT_TAKEN: 'finished_not_taken',
    FINISHED_SUCCESS: 'finished_success',
    STOPPED: 'stopped',
    DELETED: 'deleted',
})

export const WINNER_STATUS = Object.freeze({
    PENDING_PAYMENT: 'pending_payment',
    PENDING_REGISTRATION: 'pending_registration',
    PENDING_PENALTY: 'pending_penalty',
    PAID_PENALTY: 'paid_penalty',
    REGISTERED: 'registered',
    NOT_REGISTERED: 'not_registered',
})

export const AUCTION_ROUND_INFOS = Object.freeze({
    BUTTON_RESUME: 'button_resume',
    BUTTON_STOP: 'button_stop',
    AUCTION_PHASE_COMMON: 'auction_phase_common',
    AUCTION_PHASE_HIGHLIGHTED: 'auction_phase_highlighted',
    ROUND: 'round',
    ROUND_TITLE: 'round_title',
    AT_AUCTION_SINCE: 'at_auction_since',
    BIDDING_START: 'bidding_start',
    BIDDING_END: 'bidding_end',
    PENDING_REGULAR_PAYMENT_SINCE: 'pending_regular_payment_since',
    PENDING_PENALTY_PAYMENT_SINCE: 'pending_penalty_payment_since',
    PENDING_REGULAR_PAYMENT_BY: 'pending_regular_payment_by',
    PAID_SINCE: 'paid_since',
    PENALTY_PAID_SINCE: 'penalty_paid_since',
    PENDING_REGISTRATION_BY: 'pending_registration_by',
    NOT_REGISTERED_SINCE: 'not_registered_since',
    REGISTERED_SINCE: 'registered_since',
    STOPPED_SINCE: 'stopped_since',
    AUCTION_PHASE_USER_COMMON: 'auction_phase_user_common',
    AUCTION_PHASE_USER_HIGHLIGHTED: 'auction_phase_user_highlighted',
    CURRENT_PRICE: 'current_price',
    AUCTION_PRICE: 'auction_price',
    PENALTY_AMOUNT: 'penalty_amount',
    VARIABLE_SYMBOL: 'variable_symbol',
    PENALTY_VARIABLE_SYMBOL: 'penalty_variable_symbol',
    NUMBER_OF_BIDS: 'number_of_bids',
    NUMBER_OF_BIDDERS: 'number_of_bidders',
    WINNER: 'winner',
    PENALIZED: 'penalized',
})

/**
 * The definition of the visibility of every piece of information shown on the auction detail's page. Determines
 * displayed information based on the auction round's phase. Applies for the latest round.
 * Syntax: `LATEST_ROUND_INFO_VISIBILITY[<round's phase>][AUCTION_ROUND_INFOS.<information key>]`, where `true` means
 * the specified information is displayed, `false` it isn't.
 */
export const LATEST_ROUND_INFO_VISIBILITY = Object.freeze({
    [ROUND_PHASE.NEW]: {
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: true,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_ROUND_INFOS.ROUND]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: false,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: false,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: false,
        [AUCTION_ROUND_INFOS.WINNER]: false,
        [AUCTION_ROUND_INFOS.PENALIZED]: false,
    },
    [ROUND_PHASE.IN_AUCTION]: {
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: true,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_ROUND_INFOS.ROUND]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: false,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.WINNER]: false,
        [AUCTION_ROUND_INFOS.PENALIZED]: false,
    },
    [ROUND_PHASE.PENDING_PAYMENT]: {
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: true,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_ROUND_INFOS.ROUND]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: true,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: true,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: true,
        [AUCTION_ROUND_INFOS.WINNER]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: false,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.PENALIZED]: false,
    },
    [ROUND_PHASE.PENDING_REGISTRATION]: {
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: true,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_ROUND_INFOS.ROUND]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: true,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: true,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: true,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: true,
        [AUCTION_ROUND_INFOS.WINNER]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: false,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.PENALIZED]: false,
    },
    [ROUND_PHASE.FINISHED_NO_BID]: {
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_ROUND_INFOS.ROUND]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: false,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: false,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: false,
        [AUCTION_ROUND_INFOS.WINNER]: false,
        [AUCTION_ROUND_INFOS.PENALIZED]: false,
    },
    [ROUND_PHASE.PENDING_PENALTY]: {
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: true,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: true,
        [AUCTION_ROUND_INFOS.ROUND]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: true,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: true,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: true,
        [AUCTION_ROUND_INFOS.PENALIZED]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: false,
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.WINNER]: false,
    },
    [ROUND_PHASE.PAID_PENALTY]: {
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_ROUND_INFOS.ROUND]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: true,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: true,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: true,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: true,
        [AUCTION_ROUND_INFOS.PENALIZED]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.WINNER]: false,
    },
    [ROUND_PHASE.CANCELED_PENALTY]: {
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_ROUND_INFOS.ROUND]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: true,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: true,
        [AUCTION_ROUND_INFOS.PENALIZED]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: false,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.WINNER]: false,
    },
    [ROUND_PHASE.FINISHED_NOT_TAKEN]: {
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_ROUND_INFOS.ROUND]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: true,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: true,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: true,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: true,
        [AUCTION_ROUND_INFOS.WINNER]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: false,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.PENALIZED]: false,
    },
    [ROUND_PHASE.FINISHED_SUCCESS]: {
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_ROUND_INFOS.ROUND]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: true,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: true,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: true,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: true,
        [AUCTION_ROUND_INFOS.WINNER]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: false,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.PENALIZED]: false,
    },
    [ROUND_PHASE.STOPPED]: {
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: true,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: true,
        [AUCTION_ROUND_INFOS.ROUND]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: true,
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: false,
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: false,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: false,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: false,
        [AUCTION_ROUND_INFOS.WINNER]: false,
        [AUCTION_ROUND_INFOS.PENALIZED]: false,
    },
    [ROUND_PHASE.DELETED]: {
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: true,
        [AUCTION_ROUND_INFOS.ROUND]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: false,
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: false,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: false,
        [AUCTION_ROUND_INFOS.BIDDING_START]: false,
        [AUCTION_ROUND_INFOS.BIDDING_END]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: false,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: false,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: false,
        [AUCTION_ROUND_INFOS.WINNER]: false,
        [AUCTION_ROUND_INFOS.PENALIZED]: false,
    },
})

/**
 * The definition of the visibility of every piece of information shown on the auction detail's page. Determines
 * displayed information based on the auction round's state. Applies for all but the latest round.
 * Syntax: `OLDER_ROUND_INFO_VISIBILITY[<round's state>][AUCTION_ROUND_INFOS.<information key>]`, where `true` means
 * the specified information is displayed, `false` that it is not.
 */
export const OLDER_ROUND_INFO_VISIBILITY = Object.freeze({
    [ROUND_PHASE.PENDING_PENALTY]: {
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: true,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: true,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: true,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: true,
        [AUCTION_ROUND_INFOS.PENALIZED]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.ROUND]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: false,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.WINNER]: false,
    },
    [ROUND_PHASE.PAID_PENALTY]: {
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: true,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: true,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: true,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: true,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: true,
        [AUCTION_ROUND_INFOS.PENALIZED]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.ROUND]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.WINNER]: false,
    },
    [ROUND_PHASE.CANCELED_PENALTY]: {
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: true,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: true,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: true,
        [AUCTION_ROUND_INFOS.PENALIZED]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.ROUND]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: false,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.WINNER]: false,
    },
    [ROUND_PHASE.FINISHED_NOT_TAKEN]: {
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: true,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: true,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: true,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: true,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: true,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: true,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: true,
        [AUCTION_ROUND_INFOS.WINNER]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.ROUND]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: false,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.PENALIZED]: false,
    },
    [ROUND_PHASE.STOPPED]: {
        [AUCTION_ROUND_INFOS.ROUND_TITLE]: true,
        [AUCTION_ROUND_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_ROUND_INFOS.BIDDING_START]: true,
        [AUCTION_ROUND_INFOS.BIDDING_END]: true,
        [AUCTION_ROUND_INFOS.STOPPED_SINCE]: true,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_HIGHLIGHTED]: true,
        [AUCTION_ROUND_INFOS.BUTTON_RESUME]: false,
        [AUCTION_ROUND_INFOS.BUTTON_STOP]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_COMMON]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_ROUND_INFOS.ROUND]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_ROUND_INFOS.PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_PAID_SINCE]: false,
        [AUCTION_ROUND_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_ROUND_INFOS.NOT_REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PHASE_USER_COMMON]: false,
        [AUCTION_ROUND_INFOS.CURRENT_PRICE]: false,
        [AUCTION_ROUND_INFOS.AUCTION_PRICE]: false,
        [AUCTION_ROUND_INFOS.PENALTY_AMOUNT]: false,
        [AUCTION_ROUND_INFOS.VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.PENALTY_VARIABLE_SYMBOL]: false,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDS]: false,
        [AUCTION_ROUND_INFOS.NUMBER_OF_BIDDERS]: false,
        [AUCTION_ROUND_INFOS.WINNER]: false,
        [AUCTION_ROUND_INFOS.PENALIZED]: false,
    },
})

export const AUCTION_SEARCH_RESULT_INFOS = Object.freeze({
    AUCTION_PHASE_COMMON: 'auction_phase_common',
    AUCTION_PHASE_HIGHLIGHTED: 'auction_phase_highlighted',
    STOP_REASON: 'stop_reason',
    AT_AUCTION_SINCE: 'at_auction_since',
    BIDDING_START: 'bidding_start',
    BIDDING_END: 'bidding_end',
    PENDING_PENALTY_PAYMENT_SINCE: 'pending_penalty_payment_since',
    PENDING_REGULAR_PAYMENT_BY: 'pending_regular_payment_by',
    PAID_SINCE: 'paid_since',
    PENDING_REGISTRATION_BY: 'pending_registration_by',
    REGISTERED_SINCE: 'registered_since',
    NOT_REGISTERED_SINCE: 'not_registered_since',
})

/**
 * Determines the visibility of every piece of information shown in the auction search results component based
 * on the auction's latest round's state.
 * Syntax: `SEARCH_AUCTION_INFO_VISIBILITY[<round's state>][AUCTION_ROUND_INFOS.<information key>]`, where `true` means
 * the specified information is displayed, `false` that it is not.
 */
export const SEARCH_AUCTION_INFO_VISIBILITY = Object.freeze({
    [ROUND_PHASE.NEW]: {
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_START]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_SEARCH_RESULT_INFOS.STOP_REASON]: false,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_END]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PAID_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.NOT_REGISTERED_SINCE]: false,
    },
    [ROUND_PHASE.IN_AUCTION]: {
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_START]: true,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_END]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_SEARCH_RESULT_INFOS.STOP_REASON]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PAID_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.NOT_REGISTERED_SINCE]: false,
    },
    [ROUND_PHASE.PENDING_PAYMENT]: {
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_END]: true,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGULAR_PAYMENT_BY]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_SEARCH_RESULT_INFOS.STOP_REASON]: false,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_START]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PAID_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.NOT_REGISTERED_SINCE]: false,
    },
    [ROUND_PHASE.PENDING_REGISTRATION]: {
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_END]: true,
        [AUCTION_SEARCH_RESULT_INFOS.PAID_SINCE]: true,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGISTRATION_BY]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_SEARCH_RESULT_INFOS.STOP_REASON]: false,
        [AUCTION_SEARCH_RESULT_INFOS.AT_AUCTION_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_START]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.NOT_REGISTERED_SINCE]: false,
    },
    [ROUND_PHASE.FINISHED_NO_BID]: {
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AT_AUCTION_SINCE]: true,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_START]: true,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_END]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_SEARCH_RESULT_INFOS.STOP_REASON]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PAID_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.NOT_REGISTERED_SINCE]: false,
    },
    [ROUND_PHASE.PAID_PENALTY]: {
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_START]: true,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_END]: true,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGULAR_PAYMENT_BY]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_SEARCH_RESULT_INFOS.STOP_REASON]: false,
        [AUCTION_SEARCH_RESULT_INFOS.AT_AUCTION_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PAID_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.NOT_REGISTERED_SINCE]: false,

    },
    [ROUND_PHASE.CANCELED_PENALTY]: {
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_START]: true,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_END]: true,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGULAR_PAYMENT_BY]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_SEARCH_RESULT_INFOS.STOP_REASON]: false,
        [AUCTION_SEARCH_RESULT_INFOS.AT_AUCTION_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PAID_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.NOT_REGISTERED_SINCE]: false,
    },
    [ROUND_PHASE.FINISHED_NOT_TAKEN]: {
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_SEARCH_RESULT_INFOS.PAID_SINCE]: true,
        [AUCTION_SEARCH_RESULT_INFOS.NOT_REGISTERED_SINCE]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_SEARCH_RESULT_INFOS.STOP_REASON]: false,
        [AUCTION_SEARCH_RESULT_INFOS.AT_AUCTION_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_START]: false,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_END]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.REGISTERED_SINCE]: false,
    },
    [ROUND_PHASE.FINISHED_SUCCESS]: {
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_COMMON]: true,
        [AUCTION_SEARCH_RESULT_INFOS.PAID_SINCE]: true,
        [AUCTION_SEARCH_RESULT_INFOS.REGISTERED_SINCE]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_HIGHLIGHTED]: false,
        [AUCTION_SEARCH_RESULT_INFOS.STOP_REASON]: false,
        [AUCTION_SEARCH_RESULT_INFOS.AT_AUCTION_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_START]: false,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_END]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.NOT_REGISTERED_SINCE]: false,
    },
    [ROUND_PHASE.PENDING_PENALTY]: {
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_HIGHLIGHTED]: true,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_START]: true,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_END]: true,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_COMMON]: false,
        [AUCTION_SEARCH_RESULT_INFOS.STOP_REASON]: false,
        [AUCTION_SEARCH_RESULT_INFOS.AT_AUCTION_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PAID_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.NOT_REGISTERED_SINCE]: false,
    },
    [ROUND_PHASE.STOPPED]: {
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_HIGHLIGHTED]: true,
        [AUCTION_SEARCH_RESULT_INFOS.STOP_REASON]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_COMMON]: false,
        [AUCTION_SEARCH_RESULT_INFOS.AT_AUCTION_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_START]: false,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_END]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PAID_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.NOT_REGISTERED_SINCE]: false,
    },
    [ROUND_PHASE.DELETED]: {
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_HIGHLIGHTED]: true,
        [AUCTION_SEARCH_RESULT_INFOS.AUCTION_PHASE_COMMON]: false,
        [AUCTION_SEARCH_RESULT_INFOS.STOP_REASON]: false,
        [AUCTION_SEARCH_RESULT_INFOS.AT_AUCTION_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_START]: false,
        [AUCTION_SEARCH_RESULT_INFOS.BIDDING_END]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_PENALTY_PAYMENT_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGULAR_PAYMENT_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PAID_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.PENDING_REGISTRATION_BY]: false,
        [AUCTION_SEARCH_RESULT_INFOS.REGISTERED_SINCE]: false,
        [AUCTION_SEARCH_RESULT_INFOS.NOT_REGISTERED_SINCE]: false,
    },
})
