import 'vuetify/dist/vuetify.min.css'
import '@mdi/font/css/materialdesignicons.css'

import Notifications from '@remotehq/vue-notification'
import { i18n } from 'FerdaJS/app.config'
import i18next from 'i18next'
import Backend from 'i18next-chained-backend'
import Vue from 'vue'
import VueCookies from 'vue-cookies'
import Vuetify from 'vuetify/lib'

import { get_auctions_vuetify_options, get_ferda_auction_i18next_options, store } from 'ferda_auction_js/main.config'

import AuctionBaseView from './components/AuctionBaseView.vue'
import AuctionContactDetail from './components/common/AuctionContactDetail.vue'
import RelatedAuction from './components/links/RelatedAuction.vue'
import SearchRegistryResultAttachment from './components/links/SearchRegistryResultAttachment.vue'
import router from './router'

Vue.use(VueCookies)
Vue.use(Vuetify)
Vue.use(Notifications)

// Listen for store changes from Ferda and sync them with the store here
document.addEventListener('storechange', event => {
    const { payload, type } = event.detail
    const value = payload.value ? payload.value : payload

    if (store._mutations[type]) {
        store.commit(type, value)
    }
})

const destination = document.currentScript.dataset.destination

const attach_to_contact_detail = (options) => {
    const contact_data = JSON.parse(document.querySelector('#contact-data').textContent)
    const auctionEl = document.querySelector('#auction')

    if (auctionEl) {
        new Vue({
            el: '#auction',
            name: 'AuctionIndex',
            vuetify: new Vuetify(options),
            i18n,
            components: { AuctionBaseView },
            store,
            router,
            render: createElement => createElement(AuctionBaseView),
        })
    }

    const auction_section_el = document.createElement('div')
    auction_section_el.id = 'auction-section'
    document.querySelector('.v-main__wrap > div > div:nth-child(4) > div').prepend(auction_section_el)

    new Vue({
        el: '#auction-section',
        name: 'FerdaAuction',
        vuetify: new Vuetify(options),
        i18n,
        store,
        render: createElement => createElement(AuctionContactDetail, {
            props: {
                contact_id: contact_data.object_uuid,
            },
        }),
    })
}

const attach_to_domain_detail = (detail, options) => {
    const permissions = detail.store_getters['general/permissions']
    if (!permissions.includes('ferda_auction.can_view_all')) {
        return
    }
    const parent_el = document.querySelector(
        `.v-main__wrap > div > div:nth-child(3) > div:nth-child(2) > div > div`,
    )
    const related_auction_el = document.createElement('div')
    related_auction_el.id = 'related-auction'
    parent_el.prepend(related_auction_el)

    const domain_name = JSON.parse(document.querySelector('#domain-data').textContent).object_info.fqdn
    new Vue({
        el: '#related-auction',
        name: 'RelatedAuction',
        vuetify: new Vuetify(options),
        i18n,
        components: { RelatedAuction },
        store,
        render: createElement => createElement(RelatedAuction, {
            props: { domain_name },
        }),
    })
}

const attach_to_search = (detail, options) => {
    const permissions = detail.store_getters['general/permissions']
    if (!permissions.includes('ferda_auction.can_view_all')) {
        return
    }
    let auction_attachment
    const form_el = document.querySelector('.v-form')

    const search_auctions = (query_values) => {

        store.commit('auction_search/set_last_query_values', query_values)

        if (auction_attachment) {
            return
        }
        const auction_results_el = document.createElement('div')
        const found_auctions_id = 'found-auctions'
        auction_results_el.id = found_auctions_id

        form_el.insertAdjacentElement('afterend', auction_results_el)

        auction_attachment = new Vue({
            el: `#${found_auctions_id}`,
            name: 'SearchRegistryResultAttachment',
            vuetify: new Vuetify(options),
            i18n,
            components: { SearchRegistryResultAttachment },
            store,
            render: createElement => createElement(SearchRegistryResultAttachment),
        })
    }

    const urlParams = new URLSearchParams(window.location.search)
    const object_type = urlParams.get('type')
    const query_values = urlParams.getAll('query')

    if (object_type === 'domain' && query_values.length > 0) {
        search_auctions(query_values)
    }

    const searchbar = form_el.querySelector('div > div:nth-child(2) > .v-input')
    const [object_type_input] = form_el.querySelectorAll('[type="hidden"]')
    searchbar.addEventListener('keyup', (e) => {
        if (e.key !== 'Enter' || object_type_input.value !== 'domain') {
            return
        }
        const query_values = Array.from(form_el.querySelectorAll('span.v-chip--select > span'))
            .map(chip => chip.childNodes[0].nodeValue)
        search_auctions(query_values)
    })
}

const attach_to_auction_module = () => {
    const auctionEl = document.querySelector('#auction')
    if (auctionEl) {
        new Vue({
            el: '#auction',
            name: 'AuctionIndex',
            vuetify: new Vuetify(get_auctions_vuetify_options()),
            i18n,
            components: { AuctionBaseView },
            store,
            router,
            render: createElement => createElement(AuctionBaseView),
        })
    }
}

document.addEventListener('ferda-loaded', async({ detail }) => {
    await i18next.use(Backend).init(get_ferda_auction_i18next_options(detail.settings.django_settings.version))
    store.commit('auction_settings/set_auction_base_url', detail.settings.django_settings.auction.api_url)
    const options = get_auctions_vuetify_options()

    switch (destination) {
    case 'contact-detail':
        attach_to_contact_detail(options)
        break
    case 'domain-detail':
        attach_to_domain_detail(detail, options)
        break
    case 'search':
        attach_to_search(detail, options)
        break
    case 'auction-module':
        attach_to_auction_module()
        break
    }
})

window.addEventListener('popstate', () => {
    location.reload()
})

export { i18next }
