import { Store } from 'ferda/../store'

import {
    LATEST_ROUND_INFO_VISIBILITY,
    OLDER_ROUND_INFO_VISIBILITY,
    ROUND_PHASE,
    ROUND_STATUS,
    SEARCH_AUCTION_INFO_VISIBILITY,
} from 'ferda_auction_js/constants'

export const AuctionDetailModule = {
    namespaced: true,
    getters: {
        /**
         * Based on the state of this round and whether it's the latest one, returns true if the given information
         * should be displayed, and false if not.
         *
         * @returns { Boolean } The visibility information for the specified round state
         */
        is_displayed: () =>
            (is_latest, round_phase, info_name) => {
                const table = is_latest ?
                    LATEST_ROUND_INFO_VISIBILITY : OLDER_ROUND_INFO_VISIBILITY
                return table[round_phase][info_name]
            },
        /**
         * Returns the state of this round based on its status. (Status and state are often different strings.)
         *
         * @returns { String } The state of the specified round.
         */
        get_phase: () => ({ status, auction_winner }) => {
            if (status !== ROUND_STATUS.FINISHED_NOT_PAID) {
                return ROUND_PHASE[status.toUpperCase()]
            }
            if (auction_winner.penalty.closed_datetime &&
                    !auction_winner.penalty.paid_datetime) {
                return ROUND_PHASE.CANCELED_PENALTY
            }
            return ROUND_PHASE[auction_winner.status.toUpperCase()]
        },
    },
}

export const AuctionSearchAuctionModule = {
    namespaced: true,
    state: {
        last_query_values: [],
    },
    mutations: {
        /**
         * Sets the last query values in this module.
         *
         * @param { Object } state The state of this module.
         * @param { Array.<String> } value Array containing the last query values.
         */
        set_last_query_values(state, value) { state.last_query_values = value },
    },
    getters: {
        /**
         * Returns the last query values commited in this module.
         *
         * @param { Object } state The state of this module.
         * @returns { Array.<String> } Array containing the last query values commited in this module.
         */
        last_query_values: state => state.last_query_values,
        /**
         * Based on the state of the auction, returns true if the given information should be displayed, and false if
         * not.
         *
         * @returns { Boolean } The visibility information for the specified auction state
         */
        is_displayed_in_search_results: () => (round_phase, info) => {
            return SEARCH_AUCTION_INFO_VISIBILITY[round_phase][info]
        },
    },
}

export const AuctionSettingsModule = {
    namespaced: true,
    state: {
        AUCTION_BASE_URL: null,
    },
    mutations: {
        set_auction_base_url(state, value) { state.AUCTION_BASE_URL = value },
    },
    getters: {
        AUCTION_BASE_URL: state => state.AUCTION_BASE_URL,
    },
}

export const PluginStore = {
    modules: {
        ...Store.modules,
        auction_detail: AuctionDetailModule,
        auction_search: AuctionSearchAuctionModule,
        auction_settings: AuctionSettingsModule,
    },
}
